@@ -93,6 +93,10 @@ __upload_progress_css__
     color: #667799;
 }
 
+.aborted {
+    color: red;
+}
+
 .progressmeter .meter {
     position: relative;
     background-color: lightgrey;
@@ -132,7 +136,7 @@ function startPopupProgressBar(form, options) {
 
     var width  = options.width  || '480';
     var height = options.height || '150';
-    window.open ('/progress?progress_id='+id,'Apache2-UploadProgress','location=0,status=0,width='+width+',height='+height); return true;
+    window.open ('progress?progress_id='+id,'Apache2-UploadProgress','location=0,status=0,width='+width+',height='+height); return true;
 
 
 }
@@ -197,13 +201,13 @@ function updateProgressBar(progress) {
 
     progress.size     = formatBytes(progress.size);
     progress.received = formatBytes(progress.received);
-
+    
     document.getElementById('progress').innerHTML = Jemplate.process('progress.jmpl', progress);
 }
 
 function reportUploadProgress() {
     
-    url = '/progress?progress_id=' + progress.id;
+    url = 'progress?progress_id=' + progress.id;
 
     var req = new XMLHttpRequest();
     req.open('GET', url, Boolean(handleUploadProgressResults));
@@ -240,7 +244,7 @@ function handleUploadProgressResults(results) {
         progress.size         = state.size;
         progress.received     = state.received;
 
-        if ( progress.received != progress.size ) {
+        if ( progress.received != progress.size && !state.aborted ) {
             window.setTimeout( reportUploadProgress, 1000 );
         }
 
@@ -1335,8 +1339,8 @@ End Source for Jemplate - Template Toolkit for Javascript
 ------------------------------------------------------------------------------*/
 
 __upload_progress_jmpl_js__
-/* 
-   This Javascript code was generated by Jemplate, the Javascript
+/*
+   This JavaScript code was generated by Jemplate, the JavaScript
    Template Toolkit. Any changes made to this file will be lost the next
    time the templates are compiled.
 
@@ -1359,37 +1363,40 @@ output += '%;"></div>\n    <div class="percent" style="width: 100%">';
 //line 4 "progress.jmpl"
 output += stash.get('percent');
 output += '%</div>\n  </div>\n  <table>\n    <tbody>\n      <tr>\n        <th>Status:</th>\n        <td>\n';
-//line 15 "progress.jmpl"
+//line 17 "progress.jmpl"
 if (stash.get('finished')) {
 output += '          <span class="finished">Transfer complete  (';
 //line 12 "progress.jmpl"
 output += stash.get('size');
 output += ')</span>\n';
 }
+else if (stash.get('aborted')) {
+output += '          <span class="aborted">Transfer aborted</span>\n';
+}
 else {
 output += '          ';
-//line 14 "progress.jmpl"
+//line 16 "progress.jmpl"
 output += stash.get('received');
 output += ' of ';
-//line 14 "progress.jmpl"
+//line 16 "progress.jmpl"
 output += stash.get('size');
 output += '\n';
 }
 
 output += '        </td>\n      </tr>\n';
-//line 27 "progress.jmpl"
+//line 29 "progress.jmpl"
 if (stash.get('starttime')) {
 output += '      <tr>\n        <th>Time:</th>\n        <td>';
-//line 21 "progress.jmpl"
+//line 23 "progress.jmpl"
 output += stash.get('elapsedtime');
 output += ' (~ ';
-//line 21 "progress.jmpl"
+//line 23 "progress.jmpl"
 output += stash.get('remainingtime');
 output += ' to go)</td>\n      </tr>\n      <tr>\n        <th>Rate:</th>\n        <td>';
-//line 25 "progress.jmpl"
+//line 27 "progress.jmpl"
 output += stash.get('currentrate');
 output += ' (avg ';
-//line 25 "progress.jmpl"
+//line 27 "progress.jmpl"
 output += stash.get('rate');
 output += ')</td>\n      </tr>\n';
 }
@@ -1405,3 +1412,4 @@ output += '    </tbody>\n  </table>\n</span>\n';
 }
 
 
+
